/* Copyright (C) 2011, 2012, 2013 by Bundesanstalt für Gewässerkunde
 * Software engineering by Intevation GmbH
 *
 * This file is Free Software under the GNU AGPL (>=v3)
 * and comes with ABSOLUTELY NO WARRANTY! Check out the
 * documentation coming with Dive4Elements River for details.
 */

package org.dive4elements.river.artifacts.access;

import gnu.trove.TIntArrayList;

import org.apache.log4j.Logger;

import org.dive4elements.river.artifacts.D4EArtifact;


public class SedimentLoadAccess
extends      RangeAccess
{
    private static final Logger logger = Logger.getLogger(SedimentLoadAccess.class);

    private String time;
    private String unit;

    public SedimentLoadAccess(D4EArtifact artifact) {
        super(artifact);
    }

    public Double getLowerKM() {
        // TODO update callers
        return getFrom();
    }

    public Double getUpperKM() {
        // TODO update callers
        return getTo();
    }

    public String getYearEpoch() {
        if (time == null) {
            time =  getString("ye_select");
        }
        return time;
    }

    /** [startyear, endyear] if its about years. */
    public int[] getPeriod() {
        if (getYearEpoch().equals("year") ) {
            Integer start = getInteger("start");
            Integer end = getInteger("end");
            if (start == null || end == null) {
                logger.warn("No 'start' or 'end' parameter specified!");
                return null;
            }

            return new int[]{start.intValue(), end.intValue()};
        }
        return null;
    }

    public int[][] getEpochs() {
        if (!getYearEpoch().equals("epoch") &&
            !getYearEpoch().equals("off_epoch")) {
            return null;
        }

        String data = getString("epochs");

        if (data == null) {
            logger.warn("No 'epochs' parameter specified!");
            return null;
        }

        String[] parts = data.split(";");

        int[][] list = new int[parts.length][];

        for (int i = 0; i < parts.length; i++) {
            String[] values = parts[i].split(",");
            TIntArrayList ints = new TIntArrayList();
            try {
                ints.add(Integer.parseInt(values[0]));
                ints.add(Integer.parseInt(values[1]));
                list[i] = ints.toNativeArray();
            }
            catch (NumberFormatException nfe) {
                logger.warn("Cannot parse int from string: '" + values + "'");
            }
        }
        return list;
    }

    /** Returns the selected unit (t/a or m3/a). */
    public String getUnit () {
        if (unit == null) {
            unit = getString("unit");
        }
        return unit;
    }
}
// vim:set ts=4 sw=4 si et sta sts=4 fenc=utf8 :
